@@ -23,8 +23,6 @@
 
 #include "gcr-callback-output-stream.h"
 #include "gcr-collection.h"
-#define DEBUG_FLAG GCR_DEBUG_GNUPG
-#include "gcr-debug.h"
 #include "gcr-gnupg-collection.h"
 #include "gcr-gnupg-key.h"
 #include "gcr-gnupg-process.h"
@@ -51,6 +49,7 @@ struct _GcrGnupgCollectionPrivate {
 static void _gcr_collection_iface (GcrCollectionIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (GcrGnupgCollection, _gcr_gnupg_collection, G_TYPE_OBJECT,
+	G_ADD_PRIVATE (GcrGnupgCollection);
 	G_IMPLEMENT_INTERFACE (GCR_TYPE_COLLECTION, _gcr_collection_iface)
 );
 
@@ -58,8 +57,7 @@ G_DEFINE_TYPE_WITH_CODE (GcrGnupgCollection, _gcr_gnupg_collection, G_TYPE_OBJEC
 static void
 _gcr_gnupg_collection_init (GcrGnupgCollection *self)
 {
-	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, GCR_TYPE_GNUPG_COLLECTION,
-	                                        GcrGnupgCollectionPrivate);
+	self->pv = _gcr_gnupg_collection_get_instance_private (self);
 
 	self->pv->items = g_hash_table_new_full (g_str_hash, g_str_equal,
 	                                         g_free, g_object_unref);
@@ -148,7 +146,6 @@ _gcr_gnupg_collection_class_init (GcrGnupgCollectionClass *klass)
 	           g_param_spec_string ("directory", "Directory", "Gnupg Directory",
 	                                NULL, G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
-	g_type_class_add_private (gobject_class, sizeof (GcrGnupgCollectionPrivate));
 	_gcr_initialize_library ();
 }
 
@@ -308,8 +305,8 @@ process_records_as_public_key (GcrGnupgCollectionLoad *load, GPtrArray *records,
 	if (fingerprint && load->attributes)
 		attr_records = g_hash_table_lookup (load->attributes, fingerprint);
 	if (attr_records) {
-		_gcr_debug ("adding %d user id attribute(s) to key/fingerprint: %s/%s",
-		            (gint)attr_records->len, keyid, fingerprint);
+		g_debug ("adding %d user id attribute(s) to key/fingerprint: %s/%s",
+		         (gint)attr_records->len, keyid, fingerprint);
 
 		if (!g_hash_table_lookup_extended (load->attributes, fingerprint,
 		                                   (gpointer*)&orig_fingerprint, NULL))
@@ -333,13 +330,13 @@ process_records_as_public_key (GcrGnupgCollectionLoad *load, GPtrArray *records,
 
 	/* Already have this key, just update */
 	if (key) {
-		_gcr_debug ("updating public key: %s", keyid);
+		g_debug ("updating public key: %s", keyid);
 		_gcr_gnupg_key_set_public_records (key, records);
 
 	/* Add a new key */
 	} else {
 		key = _gcr_gnupg_key_new (records, NULL);
-		_gcr_debug ("creating public key: %s", keyid);
+		g_debug ("creating public key: %s", keyid);
 		g_hash_table_insert (load->collection->pv->items, g_strdup (keyid), key);
 		gcr_collection_emit_added (GCR_COLLECTION (load->collection), G_OBJECT (key));
 	}
@@ -359,7 +356,7 @@ process_records_as_secret_key (GcrGnupgCollectionLoad *load, GPtrArray *records,
 
 	/* Tell the private key that it's a secret one */
 	} else {
-		_gcr_debug ("adding secret records to key: %s", keyid);
+		g_debug ("adding secret records to key: %s", keyid);
 		_gcr_gnupg_key_set_secret_records (key, records);
 	}
 }
@@ -413,7 +410,7 @@ process_outstanding_attribute (GcrGnupgCollectionLoad *load, GcrRecord *record)
 
 	/* Do we have enough data for this attribute? */
 	if (!load->attribute_buf || load->attribute_buf->len < length) {
-		_gcr_debug ("not enough attribute data in buffer: %u", length);
+		g_debug ("not enough attribute data in buffer: %u", length);
 		return FALSE;
 	}
 
@@ -427,8 +424,8 @@ process_outstanding_attribute (GcrGnupgCollectionLoad *load, GcrRecord *record)
 		g_hash_table_insert (load->attributes, g_strdup (fingerprint), records);
 	}
 
-	_gcr_debug ("new attribute of length %d for key with fingerprint %s",
-		    length, fingerprint);
+	g_debug ("new attribute of length %d for key with fingerprint %s",
+	         length, fingerprint);
 
 	xa1 = _gcr_gnupg_build_xa1_record (record, load->attribute_buf->data, length);
 	g_ptr_array_add (records, xa1);
@@ -454,8 +451,8 @@ process_outstanding_attributes (GcrGnupgCollectionLoad *load)
 	if (load->attribute_queue == NULL)
 		return;
 
-	_gcr_debug ("%d outstanding attribute records",
-	            (gint)g_queue_get_length (load->attribute_queue));
+	g_debug ("%d outstanding attribute records",
+	         (gint)g_queue_get_length (load->attribute_queue));
 
 	for (;;) {
 		record = g_queue_peek_head (load->attribute_queue);
@@ -475,7 +472,7 @@ on_line_parse_output (const gchar *line, gpointer user_data)
 	GcrRecord *record;
 	GQuark schema;
 
-	_gcr_debug ("output: %s", line);
+	g_debug ("output: %s", line);
 
 	record = _gcr_record_parse_colons (line, -1);
 	if (!record) {
@@ -490,7 +487,7 @@ on_line_parse_output (const gchar *line, gpointer user_data)
 	 * it's a new key being listed.
 	 */
 	if (schema == GCR_RECORD_SCHEMA_PUB || schema == GCR_RECORD_SCHEMA_SEC) {
-		_gcr_debug ("start of new key");
+		g_debug ("start of new key");
 		if (load->records->len)
 			process_records_as_key (load);
 		g_assert (!load->records->len);
@@ -600,13 +597,13 @@ on_gnupg_process_completed (GObject *source, GAsyncResult *result, gpointer user
 	/* If we completed loading public keys, then go and load secret */
 	switch (load->loading_phase) {
 	case GCR_LOADING_PHASE_PUBLIC:
-		_gcr_debug ("public load phase completed");
+		g_debug ("public load phase completed");
 		load->loading_phase = GCR_LOADING_PHASE_SECRET;
 		spawn_gnupg_list_process (load, res);
 		g_object_unref (res);
 		return;
 	case GCR_LOADING_PHASE_SECRET:
-		_gcr_debug ("secret load phase completed");
+		g_debug ("secret load phase completed");
 		/* continue below */
 		break;
 	default:
@@ -619,7 +616,7 @@ on_gnupg_process_completed (GObject *source, GAsyncResult *result, gpointer user
 		object = g_hash_table_lookup (load->collection->pv->items, keyid);
 		if (object != NULL) {
 			g_object_ref (object);
-			_gcr_debug ("removing key no longer present in keyring: %s", (gchar*)keyid);
+			g_debug ("removing key no longer present in keyring: %s", (gchar*)keyid);
 			g_hash_table_remove (load->collection->pv->items, keyid);
 			gcr_collection_emit_removed (GCR_COLLECTION (load->collection), object);
 			g_object_unref (object);
@@ -640,14 +637,14 @@ spawn_gnupg_list_process (GcrGnupgCollectionLoad *load, GSimpleAsyncResult *res)
 
 	switch (load->loading_phase) {
 	case GCR_LOADING_PHASE_PUBLIC:
-		_gcr_debug ("starting public load phase");
+		g_debug ("starting public load phase");
 		g_ptr_array_add (argv, (gpointer)"--list-keys");
 		/* Load photos in public phase */
 		flags = GCR_GNUPG_PROCESS_WITH_ATTRIBUTES |
 		        GCR_GNUPG_PROCESS_WITH_STATUS;
 		break;
 	case GCR_LOADING_PHASE_SECRET:
-		_gcr_debug ("starting secret load phase");
+		g_debug ("starting secret load phase");
 		g_ptr_array_add (argv, (gpointer)"--list-secret-keys");
 		break;
 	default:
