@@ -15,9 +15,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
@@ -25,7 +23,8 @@
 #include "config.h"
 
 #include "gcr-collection-model.h"
-#include "gcr-enum-types.h"
+
+#include "ui/gcr-enum-types.h"
 
 #include <gtk/gtk.h>
 
@@ -135,6 +134,7 @@ static void gcr_collection_model_tree_model_init (GtkTreeModelIface *iface);
 static void gcr_collection_model_tree_sortable_init (GtkTreeSortableIface *iface);
 
 G_DEFINE_TYPE_EXTENDED (GcrCollectionModel, gcr_collection_model, G_TYPE_OBJECT, 0,
+                        G_ADD_PRIVATE (GcrCollectionModel);
                         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, gcr_collection_model_tree_model_init)
                         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_SORTABLE, gcr_collection_model_tree_sortable_init)
 );
@@ -1137,7 +1137,7 @@ gcr_collection_model_tree_sortable_init (GtkTreeSortableIface *iface)
 static void
 gcr_collection_model_init (GcrCollectionModel *self)
 {
-	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, GCR_TYPE_COLLECTION_MODEL, GcrCollectionModelPrivate);
+	self->pv = gcr_collection_model_get_instance_private (self);
 
 	self->pv->root_sequence = g_sequence_new (NULL);
 	self->pv->object_to_seq = g_hash_table_new (g_direct_hash, g_direct_equal);
@@ -1260,8 +1260,6 @@ gcr_collection_model_class_init (GcrCollectionModelClass *klass)
 	g_object_class_install_property (gobject_class, PROP_COLUMNS,
 		g_param_spec_pointer ("columns", "Columns", "Columns for the model",
 		                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-
-	g_type_class_add_private (klass, sizeof (GcrCollectionModelPrivate));
 }
 
 /**
@@ -1386,6 +1384,13 @@ gcr_collection_model_get_collection (GcrCollectionModel *self)
 	return self->pv->collection;
 }
 
+/**
+ * gcr_collection_model_set_collection:
+ * @self: a collection model
+ * @collection: (allow-none): the collection or %NULL
+ *
+ * Set the collection which this model represents
+ */
 void
 gcr_collection_model_set_collection (GcrCollectionModel *self,
                                      GcrCollection *collection)
